@@ -400,6 +400,20 @@ func (r *resourceAdapter) getImageOps() images.ImageResourceOps {
 	return img
 }
 
+// IsImage reports whether the given resource is an image that can be processed.
+func IsImage(v any) bool {
+	r, ok := v.(resource.Resource)
+	if !ok {
+		return false
+	}
+	mt := r.MediaType()
+	if mt.MainType != "image" {
+		return false
+	}
+	_, isImage := images.ImageFormatFromMediaSubType(mt.SubType)
+	return isImage
+}
+
 func (r *resourceAdapter) publish() {
 	if r.publishOnce == nil {
 		return
